@@ -27,15 +27,13 @@ impl PrivateNameMangler {
         let new_sym = if let Some(cached) = self.renamed_private.get(&id) {
             cached.clone()
         } else {
-            loop {
-                let sym = incr_base54(&mut self.private_n).1;
+            let sym = incr_base54(&mut self.private_n).1;
 
-                let sym: JsWord = sym.into();
+            let sym: JsWord = sym.into();
 
-                self.renamed_private.insert(id.clone(), sym.clone());
+            self.renamed_private.insert(id.clone(), sym.clone());
 
-                break sym;
-            }
+            sym
         };
 
         private_name.id.sym = new_sym;
